@@ -100,8 +100,8 @@ class Domoticz(IPlugin):
 				log.msg("response   :  %s" % (jsonreq))
 				log.msg("*********************************************  : ")
 				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
-				len = len(jsonreq['result'])
-				log.msg(" len len   :  %s" % (len))	
+				total = len(jsonreq['result'])
+				log.msg(" len len   :  %s" % (total))	
 				for xx in len:
 					log.msg(" jsonreq - idx   :  %s" % (xx(idx)))
 					log.msg("   jsonreq - type   :  %s" % (xx(Type)))
